---
from "src/components/user.nexy" import User
title  = ["About Page","About"] 
# name:prop[str] = "About Page"
# slug:prop[str]
def user(): 
    return "John Doe"

class Main:
    def get(): pass
---
# mdx page
bonjour! This is the about page of Nexy. 
Nexy is a static site generator that helps you build fast and modern websites with ease.
{{ name }}

<title>Bonjour</title>
![Go to Home]("/public/vite.svg")
<img src="/public/vite.svg" alt="Go to Home"  style="width: 100px; height: 100px;"/>
{%for item in title %}
1. {{ item }}

{% endfor %}
---
<User>
```python
 def user():
    print("user")

```
</User>
dhj
